# dblpy
**Dblpy** is a simple wrapper library for the dblp.org search api.

```py
from dblpy import get_authors, get_venues, get_publications

authors = get_authors(q='Donald Knuth')
for a in authors:
    print(a.name)

    for n in a.notes:
        print(f'|{n}')

publications = get_publications(q='gps trajectory', max_results=5)
for p in publications:
    print(p)

venues = get_venues(q='Berlin')
for v in venues:
    print(v)
```
